<?php

namespace Litecms\Addon\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Addon\Models\Addons;

class AddonsPolicy
{

    /**
     * Determine if the given user can view the addons.
     *
     * @param UserPolicy $user
     * @param Addons $addons
     *
     * @return bool
     */
    public function view(UserPolicy $user, Addons $addons)
    {
        if ($user->canDo('addon.addons.view') && $user->isAdmin()) {
            return true;
        }

        return $addons->user_id == user_id() && $addons->user_type == user_type();
    }

    /**
     * Determine if the given user can create a addons.
     *
     * @param UserPolicy $user
     * @param Addons $addons
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('addon.addons.create');
    }

    /**
     * Determine if the given user can update the given addons.
     *
     * @param UserPolicy $user
     * @param Addons $addons
     *
     * @return bool
     */
    public function update(UserPolicy $user, Addons $addons)
    {
        if ($user->canDo('addon.addons.edit') && $user->isAdmin()) {
            return true;
        }

        return $addons->user_id == user_id() && $addons->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given addons.
     *
     * @param UserPolicy $user
     * @param Addons $addons
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Addons $addons)
    {
        return $addons->user_id == user_id() && $addons->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given addons.
     *
     * @param UserPolicy $user
     * @param Addons $addons
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Addons $addons)
    {
        if ($user->canDo('addon.addons.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given addons.
     *
     * @param UserPolicy $user
     * @param Addons $addons
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Addons $addons)
    {
        if ($user->canDo('addon.addons.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
